% Euler-Bernoulli Beam-column model for wind and marine turbines
% S Adhikari,
% Started: 16 January 2009
% CONSIDERS TWO PARAMETER (\nu and \eta_r) VARIATIONS: => 3D PLOTS
% The plots are drwan for some particular values of \eta_t which acts as
% the global loop
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all; close all;
fsize=14; fname='times';
global nu eta_r eta_t alpha_p beta_p fct0 

% Main parameters
 E=2.1e11;
 rho=7800;
 L=81;
 D=3.5;
 t=0.075;
 M=130000; J=0.0;
 [nu_example(1),alpha_p_example(1),beta_p,fct0_example(1),I_example(1),m_example(1),P_example(1),r_example(1),mu_example(1),A_example(1)]=nd_parameters(E,rho,L,D,t,M,J); 
 omega_example(1)=0.37;  %Passing frequency in Hz
 r_example(1)=sqrt(I_example(1)/A_example(1))

 
% Generate and store parameter points
nu_min=0.001;nu_max=1.0;n_nu=30;
nu_array=nu_min: (nu_max-nu_min)/(n_nu-1): nu_max;
    
eta_min=1.0;eta_max=200.;n_eta=35;
eta_array=eta_min: (eta_max-eta_min)/(n_eta-1): eta_max;

axis_vector=[0 nu_max 0 eta_max 0 0.601];

eta_t_array=[1 5 10 100];
ne=length(eta_t_array);

fct0=fct0_example(1);
options = optimset('Display','off');  % Turn off Display 
% only Exitflag= 1 values can be trusted * * * * IMPORTANT * * * 


for kk=1:ne
    eta_t=eta_t_array(kk);
		for ii=1:n_nu
		    nu=nu_array(ii);            % PL^2/EI
		    alpha_p=nu*fct0^2*L/9.8074;
		    for jj=1:n_eta          		 
				eta_r=eta_array(jj);        % nondimensional support stiffness                        
		        x0=ApproxNaturalFrequency;            
		        [x,Fval,exitflag] = fsolve(@FrequencyFunction,x0,options);      
		        omegan_E(ii,jj)=sqrt(x); 
		        omegan_approx(ii,jj)=sqrt(x0); 
		        %disp(['nu=: ' num2str(nu) ', Exitflag= ' int2str(exitflag) ', Fval=' num2str(real(Fval)) ]);        
		    end
		end
    omegan_E_all{kk}=omegan_E;
    omegan_approx_all{kk}=omegan_approx;
end
% Create the 3D plots
[x1,y1]=meshgrid(nu_array,eta_array);   

% Interplate to have smooth plots
resolution_factor=2;
nu_array2=nu_min: (nu_max-nu_min)/(n_nu*resolution_factor-1): nu_max;
eta_array2=eta_min: (eta_max-eta_min)/(n_eta*resolution_factor-1): eta_max;
[x2,y2]=meshgrid(nu_array2,eta_array2);   

save etat_fixed_3DPlotData;
clear all;

%------------load data ---------
load etat_fixed_3DPlotData;

for kk=1:ne
    eta_t=eta_t_array(kk);
	dataj=interp2(x1,y1,fct0/2/pi*omegan_E_all{kk}.',x2,y2);    
    
    figure(2*kk-1);clf; hold all;
    surfc(x2,y2,real(dataj));    
    xlabel('\nu = PL^2/EI','FontName',fname,'fontsize',fsize);
    ylabel('\eta_r = k_r L/EI','FontName',fname,'fontsize',fsize);
    zlabel('\omega_1 = \Omega_1 f_0 (Hz)','FontName',fname,'fontsize',fsize);  
    axis(axis_vector);
    view(35,5);
    ha=gca;set(ha,'linewidth',1.5,'FontName',fname,'FontSize',fsize);
    eval(['print -depsc figures/omega1_nu_eta_var_etat' num2str(eta_t) '.eps']);
    eval(['print -djpeg100 figures/omega1_nu_eta_var_etat' num2str(eta_t) '.jpeg']);   

    figure(2*kk);clf;
    [C,h] = contour(x2,y2,dataj);hold on;
    clabel(C,h)
    xlabel('\nu = PL^2/EI','FontName',fname,'fontsize',fsize);
    ylabel('\eta_r = k_r L/EI','FontName',fname,'fontsize',fsize);
    ha=gca;set(ha,'linewidth',1.5,'FontName',fname,'FontSize',fsize,'Box','on');
    %eval(['print -depsc figures/omega1_nu_eta_contour_etat' num2str(eta_t) '.eps']);
    %eval(['print -djpeg100 figures/omega1_nu_eta_contour_etat' num2str(eta_t) '.jpeg']);    
end    

